/*******************************************************************************
	
		analysis_bg.do
		5.21.2020
		Main analysis for:
		"Values and Inequality"
		Nathan Wilmers and Letian Zhang
		
 	IN:
		/data/
			bg_using.dta 
				Built by: 
				build_bg.do
				
			cepr_org_allyears.dta
				Built by:
				code/cepr_cps.do
		
	OUT:
		/data/ 
			none
				
		/results/
				descriptives.tex
				occupations.tex
				cpsbgtrend.pdf/gph
				occ_anysocial.pdf/gph
				ind_anysocial.pdf/gph
				collegetrend.pdf/gph
				prosocialmain.tex
		
*******************************************************************************/
global sec1  1  // 	SECTION 1. Validating social measure
global sec2  1  // 	SECTION 2. Descriptive table
global sec3  1  // 	SECTION 3. Occupation comparisons
global sec4  1  // 	SECTION 4. CPS-BG comparison
global sec5  1  // 	SECTION 5. Pro-social shares by industry and occupation
global sec6  1  // 	SECTION 6. Social college/non-college
global sec7  1  // 	SECTION 7. Social wage effects table
global sec8  1  // 	SECTION 8. Social wage panel models
global sec9  1  // 	SECTION 9. Inequality effects

global presentation 1
global paper 1

*-------------------------------------------------------------------------------
* PRELIMINARIES
*-------------------------------------------------------------------------------

// Set working directory
global user Nate

if "$user"=="Nate" {
	cd "/Users/wilmers/Dropbox (MIT)/stata/bg/"
}

use data/bg_using.dta, clear

*-------------------------------------------------------------------------------
* SECTION 1. Validating social measure
*-------------------------------------------------------------------------------
if $sec1 {	

// Keep only one observation per MSA
bys year msa: gen count=_n

// MSA descriptives
corr msa_volunteer msa_anysocial if count==1
local rho1: di %6.2f r(rho)

binscatter msa_volunteer msa_anysocial if count==1, ///
nq(25) ///
mcolor(black) msymbol(circle_hollow) lcolor(gs10) ///
ylabel(, nogrid) graphregion(style(none) color(gs16)) ///
xtitle("MSA-level Proportion of Pro-Social Jobs") ///
ytitle("MSA-level Volunteer Share") ///
text(.27 .75 "{&rho} =`rho1'")
graph save results/bin_volunteer.gph, replace
graph export results/bin_volunteer.pdf, replace

// Variation by college/non-college
tab college [aw = weight], sum(anysocial)
reg anysocial college [aw = weight]
reghdfe anysocial college [aw = weight], absorb(employers)
reghdfe anysocial college [aw = weight], absorb(naics3)

}

*-------------------------------------------------------------------------------
* SECTION 2. Descriptive table
*-------------------------------------------------------------------------------
if $sec2 {	
	
local descriptives lnsalary anysocial lntext lnskill_count exp bonus parttime

// Descriptive table
eststo noncoll: estpost summarize ///
 `descriptives' if college == 0 [aw = weight]
eststo coll: estpost summarize ///
 `descriptives' if college == 1 [aw = weight]
		
local note="Note: Data are Burning Glass."
wordwrap "`note'", l(10)
local noteshort=r(text)
di "`noteshort'"
	 
esttab noncoll coll using results/descriptives.tex, ///
cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") nomtitles ///
mgroups("Non-college" "College", pattern(1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
title("Descriptive Statistics"\label{tab:descriptives}) ///
label replace nogaps lines compress nodepvars nonumbers ///
addnote("Note: Data are Burning Glass.")
}

*-------------------------------------------------------------------------------
* SECTION 3. Occupation comparisons
*-------------------------------------------------------------------------------

if $sec3 {	

preserve
// Occupation representivity
*keep if year==2019
gen unit=1
keep if soc_short!=. & soc_short!=55
collapse (sum) weight unit, by(soc_short)
	
egen total=total(weight)
gen bg_share_w=weight/total
drop total weight
	
egen total=total(unit)
gen bg_share_wu=unit/total
drop total unit
	
merge 1:1 soc_short using data/oes_occ_only.dta, nogen
	
estpost tabstat bg_share_wu bg_share_w oes_share, by(soc_short) nototal
est store weight
	
local note="Note: Weighted Burning Glass series is weighted based on occupation, state and occupation employment totals from the 2019 Occupational Employment Statistics (OES)."
wordwrap "`note'", l(80)
local noteshort=r(text)
di "`noteshort'"
	
esttab weight using results/occupations.tex ///
, cells("bg_share_wu(fmt(2) label(\shortstack{Burning Glass\\unweighted})) bg_share_w(fmt(2) label(\shortstack{Burning Glass\\weighted})) oes_share(fmt(2) label(OES 2019)) ") ///
nolabel nomtitles noobs label replace nogaps lines compress nodepvars nonumbers ///
title("Occupational Shares in Burning Glass and OES"\label{tab:occupations}) ///
addnote("`noteshort'")

restore 

}
*-------------------------------------------------------------------------------
* SECTION 4. CPS-BG comparison
*-------------------------------------------------------------------------------
if $sec4 {	

// With CPS
reg lnsalary i.year i.year#i.college lntext if parttime==0 [aw = weight]
*reghdfe lnsalary i.year i.year#i.college, absorb(i.text)
est store bgtrend

preserve

do code/cepr_cps.do

foreach var in rw {
gen ln`var'=ln(`var')
}
gen college=educ>3
reg lnrw i.year i.year#i.college [aw = orgwgt] if educ>1
est store cpstrend

sum rw if year==2018 & college [aw = orgwgt]
sum rw if year==2018 & college==0 [aw = orgwgt]
sum rw if year==1980 & college [aw = orgwgt]
sum rw if year==1980 & college==0 [aw = orgwgt]

sum lnrw if year==2018 & college [aw = orgwgt]
sum lnrw if year==2018 & college==0 [aw = orgwgt]
sum lnrw if year==1980 & college [aw = orgwgt]
sum lnrw if year==1980 & college==0 [aw = orgwgt]

restore


coefplot ///
(cpstrend, lcolor(black) msymbol(none) noci lwidth(medthick)  mlabels(1995.year#1.college = 12 "CPS-ORG") mlabcolor(black)) ///
(bgtrend, lcolor(black) msymbol(none) noci lwidth(medthick) lpattern(dash)  mlabels(2012.year#1.college = 6 "Burning Glass") mlabcolor(black)) ///
, keep(*year#1.college) vertical baselevels ///
ylabel(0(.1).7, nogrid) graphregion(color(white)) plotregion() ///
yscale(range(0 .7)) ///
ytitle("College Wage Premium") ///
recast(connected) ///
legend(off) ///
coeflabels( ///
1979*=" " ///
1980*=1980 ///
1981*=" " ///
1982*=" " ///
1983*=" " ///
1984*=" " ///
1985*=1985 ///
1986*=" " ///
1987*=" " ///
1988*=" " ///
1989*=" " ///
1990*=1990 ///
1991*=" " ///
1992*=" " ///
1993*=" " ///
1994*=" " ///
1995*=1995 ///
1996*=" " ///
1997*=" " ///
1998*=" " ///
1999*=" " ///
2000*=2000 ///
2001*=" " ///
2002*=" " ///
2003*=" " ///
2004*=" " ///
2005*=2005 ///
2006*=" " ///
2007*=" " ///
2008*=" " ///
2009*=" " ///
2010*=2010 ///
2011*=" " ///
2012*=" " ///
2013*=" " ///
2014*=" " ///
2015*=2015 ///
2016*=" " ///
2017*=" " ///
2018*=" " ///
2019*=2019)
graph save results/cpsbgtrend.gph, replace
graph export results/cpsbgtrend.pdf, replace

}

*-------------------------------------------------------------------------------
* SECTION 5. Pro-social shares by industry and occupation
*-------------------------------------------------------------------------------
if $sec5 {	

// Occupation
graph dot ///
anysocial ///
[aw = weight] ///
, over(soc_short, sort(1) descending) ///
exclude0 ///
plotregion(color(white)) graphregion(color(white)) ///
marker(1, msymbol(circle) mcolor(black) msize(medium)) ///
legend(off) ///
ytitle("Pro-social Share", size(medium)) ylabel(, labsize(medium))
graph save results/occ_anysocial.gph, replace
graph export results/occ_anysocial.pdf, replace

// Industry
graph dot ///
anysocial ///
[aw = weight] ///
, over(sectorname, sort(1) descending) ///
exclude0 ///
plotregion(color(white)) graphregion(color(white)) ///
marker(1, msymbol(circle) mcolor(black) msize(medium)) ///
legend(off) ///
ytitle("Pro-social Share", size(medium)) ylabel(, labsize(medium))
graph save results/ind_anysocial.gph, replace
graph export results/ind_anysocial.pdf, replace
}

*-------------------------------------------------------------------------------
* SECTION 6. Social college/non-college
*-------------------------------------------------------------------------------
if $sec6 {	

reghdfe lnsalary [aw = weight], absorb(i.text) resid(resid)
replace resid=resid+_b[_cons]

bys college anysocial year: egen tsalary=wtmean(resid), weight(weight)
bys college anysocial year: gen dup=cond(_N==1,0,_n)
bys college anysocial year: egen n=total(weight)

local socialcolor gs8
twoway ///
(scatter tsalary year if college==1 & anysocial==0 & dup<2 [aw = n], c(l) msymbol(circle_hollow) mcolor(black) lcolor(black) lwidth(medthick) lpattern(solid)) ///
(scatter tsalary year if college==1 & anysocial==1 & dup<2 [aw = n], c(l) msymbol(circle_hollow) mcolor(`socialcolor') lcolor(`socialcolor') lwidth(medthick) lpattern(solid)) ///
(scatter tsalary year if college==0 & anysocial==0 & dup<2 [aw = n], c(l) msymbol(circle_hollow) mcolor(black) lcolor(black) lwidth(medthick) lpattern(solid)) ///
(scatter tsalary year if college==0 & anysocial==1 & dup<2 [aw = n], c(l) msymbol(circle_hollow) mcolor(`socialcolor') lcolor(`socialcolor') lwidth(medthick) lpattern(solid)) ///
, xtitle("") ytitle("log(Annual Salary)", size(small)) ///
ylabel(, nogrid labsize(small)) ///
xlabel(, labsize(small)) plotregion(color(white)) ///
graphregion(color(white)) ///
legend(col(1) symxsize(6) order(1 2) label(1 "Standard") label(2 "Pro-social") ///
position(4) ring(1) size(medium) region(lcolor(white))) ///
text(10.95 2006 "College", place(e)) ///
text(10.55 2006 "Non-college", place(e))
drop tsalary dup resid n
graph save results/collegetrend.gph, replace
graph export results/collegetrend.pdf, replace
}

*-------------------------------------------------------------------------------
* SECTION 7. Social wage effects table
*-------------------------------------------------------------------------------
if $sec7 {	

// How many skill sets?
egen skillcomboXsoc=group(skillcombo soc)
codebook skillcomboXsoc skillcombo
bys skillcomboXsoc: gen singlet=_N
codebook skillcomboXsoc skillcombo if singlet>1

local predbase i.college lntext lnskill_count exp bonus parttime
local pred i.anysocial##i.college lntext lnskill_count exp bonus parttime
local lm i.year#i.msa#i.naics3#i.college
local occ i.soc
local dv lnsalary
local cluster i.naics3
*local cluster employer


reghdfe `dv' `predbase' [aw = weight], absorb(i.year) cluster(`cluster')
est store base
reghdfe `dv' `pred' [aw = weight], absorb(i.year) cluster(`cluster')
est store first
reghdfe `dv' `pred' [aw = weight], absorb(`lm') cluster(`cluster')
est store lm
reghdfe `dv' `pred' [aw = weight], absorb(`lm' `occ') cluster(`cluster')
est store occ
reghdfe `dv' `pred' [aw = weight], absorb(`occ'#i.skillcombo `lm') cluster(`cluster')
est store skillint

estadd local year  "$\times$", replace: base first
estadd local lm "$\times$", replace: lm occ skillint
estadd local occ "$\times$", replace: occ
estadd local skill "$\times$", replace: skillint
estadd local controls "$\times$", replace: base first lm occ skillint

// For paper
if $paper {
local note="Note: Data are Burning Glass.  All postings with non-missing salary, industry and education information included.  Standard errors are clustered at the 3-digit industry level."
wordwrap "`note'", l(80)
local noteshort=r(text)
di "`noteshort'"

esttab base first lm occ skillint using results/prosocialmain.tex, replace ///
b(3) se(3) star obslast r2(2) label nogaps nobaselevels lines nomtitles nonotes ///
nodepvars noomitted interaction(" * ") ///
order(1.college *1.anysocial*) ///
scalar("hello Fixed effects:" ///
"year \hspace{.1cm} Year" ///
"lm \hspace{.1cm} Year X Ind. X MSA X College" ///
"occ \hspace{.1cm} Occup." ///
"skill \hspace{.1cm} Occup. X Skill set") ///
title("Pro-social Jobs Earning Penalty if College Degree Required"\label{tab:prosocialmain}) ///
addnote("`noteshort'" ///
"* p $<$ .05; ** p $<$ .01; *** p $<$ .001 (two-tailed tests)")
}

// For presentation
if $presentation {
esttab base first lm occ skillint using results/prosocialmain_pres.tex, replace ///
b(3) se(3) star obslast r2(2) label nogaps nobaselevels lines nomtitles nonotes ///
nodepvars noomitted interaction(" * ") drop(lntext lnskill_count exp bonus parttime _cons) ///
scalar("controls Controls" ///
"hello Fixed effects:" ///
"year \hspace{.1cm} Year" ///
"lm \hspace{.1cm} Year X Ind. X MSA" ///
"occ \hspace{.1cm} Occup." ///
"skill \hspace{.1cm} Occup. X Skill set") ///
addnote("Note: Data are Burning Glass.  SEs clustered at the Industry X Year level.")
}

local cluster i.employer
local predbase i.college lntext lnskill_count exp bonus parttime
local pred i.anysocial##i.college lntext lnskill_count exp bonus parttime
local lm i.year#i.msa#i.naics3#i.college
local occ i.soc
local dv lnsalary

reghdfe `dv' `predbase' [aw = weight], absorb(i.year) cluster(`cluster')
est store base
reghdfe `dv' `pred' [aw = weight], absorb(i.year) cluster(`cluster')
est store first
reghdfe `dv' `pred' [aw = weight], absorb(`lm') cluster(`cluster')
est store lm
reghdfe `dv' `pred' [aw = weight], absorb(`lm' `occ') cluster(`cluster')
est store occ
reghdfe `dv' `pred' [aw = weight], absorb(`lm' `occ'#i.skillcombo) cluster(`cluster')
est store skillint

estadd local year  "$\times$", replace: base first
estadd local lm "$\times$", replace: lm occ skillint
estadd local occ "$\times$", replace: occ
estadd local skill "$\times$", replace: skillint
estadd local controls "$\times$", replace: base first lm occ skillint

// For paper (employer cluster, for reviewer: not main result, as it drops missing employer postings)
if $paper {
local note="Note: Data are Burning Glass.  All postings with non-missing salary, industry and education information included.  Standard errors are clustered at the employer level."
wordwrap "`note'", l(80)
local noteshort=r(text)
di "`noteshort'"

esttab base first lm occ skillint using results/prosocialempcluster.tex, replace ///
b(3) se(3) star obslast r2(2) label nogaps nobaselevels lines nomtitles nonotes ///
nodepvars noomitted interaction(" * ") ///
scalar("hello Fixed effects:" ///
"year \hspace{.1cm} Year" ///
"lm \hspace{.1cm} Year X Ind. X MSA X College" ///
"occ \hspace{.1cm} Occup." ///
"skill \hspace{.1cm} Occup. X Skill set") ///
title("Pro-social Jobs Earning Penalty if College Degree Required"\label{tab:prosocialmain}) ///
addnote("`noteshort'" ///
"* p $<$ .05; ** p $<$ .01; *** p $<$ .001 (two-tailed tests)")
}

}

*-------------------------------------------------------------------------------
* SECTION 8. Social wage panel model
*-------------------------------------------------------------------------------
if $sec8 {	

*egen job=group(employer cleantitle msa)
egen job=group(employer soc msa)

local cluster i.naics3
local pred i.anysocial lntext lnskill_count exp bonus parttime
local lm i.year#i.msa#i.naics3
local occ soc
local dv lnsalary

forval c=0/1 {
reghdfe `dv' `pred' if college==`c' [aw = weight], absorb(i.job i.year)
est store panelfirst`c'
reghdfe `dv' `pred' if college==`c' [aw = weight], absorb(i.job i.`lm')
est store panellm`c'
reghdfe `dv' `pred' if college==`c' [aw = weight], absorb(i.job#i.skillcombo i.`lm')	
est store panelskill`c'

estadd local job  "$\times$", replace: panelfirst`c' panellm`c'
estadd local year  "$\times$", replace: panelfirst`c'
estadd local lm "$\times$", replace: panellm`c' panelskill`c'
estadd local skill "$\times$", replace: panelskill`c'
estadd local controls "$\times$", replace: panelfirst`c' panellm`c' panelskill`c'
}
estadd local skillpart "$\times$", replace:
estadd local jobpart "$\times$", replace:

local note="Note: Data are Burning Glass.  All postings with non-missing employer, salary, industry and education information included. Controls are log(text length), experience required, bonus paid and part-time job.  Standard errors are clustered at the Industry X Year level."
wordwrap "`note'", l(100)
local noteshort=r(text)
di "`noteshort'"

// For paper
esttab panelfirst0 panellm0 panelskill0 panelfirst1 panellm1 panelskill1 using results/prosocialpanel.tex, replace ///
b(3) se(3) star obslast r2(2) label nogaps nobaselevels lines nomtitles nonotes ///
nodepvars noomitted interaction(" * ") ///
keep(*1.anysocial*) ///
mgroups("Non-college" "College", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
scalar("controls Controls" ///
"hello Fixed effects:" ///
"job \hspace{.1cm} Emp. X MSA X Occ." ///
"year \hspace{.1cm} Year" ///
"lm \hspace{.1cm} Year X Ind. X MSA" ///
"skill \hspace{.1cm} Emp. X MSA X Occ. X" ///
"jobpart \hspace{.4cm} Skill set") ///
title("Earnings Effects of a Job Switching to Pro-social"\label{tab:prosocialpanel}) ///
addnote("`noteshort'" ///
"* p $<$ .05; ** p $<$ .01; *** p $<$ .001 (two-tailed tests)")

}
*-------------------------------------------------------------------------------
* SECTION 9. Inequality effects
*-------------------------------------------------------------------------------

if $sec9 {	

use data/bg_using.dta, clear

// Model of college wage premium at the MSA level

// College wage premium
bys year msa: egen collnsalaryt=wtmean(lnsalary) if college==1, weight(weight)
bys year msa: egen nocollnsalaryt=wtmean(lnsalary) if college==0, weight(weight)
bys year msa: egen collnsalary=max(collnsalaryt)
bys year msa: egen nocollnsalary=max(nocollnsalaryt)
gen msa_coll_gap_bg=collnsalary-nocollnsalary

// Share of college jobs (really want college-educated?)
bys year msa: egen msa_coll_share=wtmean(college), weight(weight)

// Keep only one observation per MSA
bys msa  year: gen msa_keep=_n

corr msa_coll_gap_bg msa_anysocial if msa_keep==1

// Set locals
local pred msa_anysocial
local controls msa_collunem msa_nocollnunem msa_coll_cps msa_age msa_union msa_pubsect msa_female

// CPS gap
reghdfe msa_coll_gap `pred' if msa_keep==1 & msa_collunem!=., noabsorb
est store cpsbase
reghdfe msa_coll_gap `pred' `controls' if msa_keep==1, noabsorb
est store cpscontrols
reghdfe msa_coll_gap `pred' `controls' if msa_keep==1, absorb(i.msa) 
est store cpsmsa

// BG gap
reghdfe msa_coll_gap_bg `pred' if msa_keep==1 & msa_collunem!=., noabsorb
est store bgbase
reghdfe msa_coll_gap_bg `pred' `controls' if msa_keep==1, noabsorb
est store bgcontrols
reghdfe msa_coll_gap_bg `pred' `controls' if msa_keep==1, absorb(i.msa) 
est store bgmsa

estadd local controls "$\times$", replace: cpscontrols cpsmsa bgcontrols bgmsa
estadd local lm "$\times$", replace: cpsmsa bgmsa

local note="Note: Data are Burning Glass and CPS-ORG, aggregated to MSA-by-year level.  Controls are from CPS-ORG: unemployment rates for college and non-college workers; share college workers out of total labor force; average age (as a proxy for workforce experience); share women; union density; share public sector; and year."
wordwrap "`note'", l(95)
local noteshort=r(text)
di "`noteshort'"

// For paper
esttab cpsbase cpscontrols cpsmsa bgbase bgcontrols bgmsa using results/msa.tex, replace ///
b(3) se(3) r2(2) star obslast label nogaps nobaselevels lines nomtitles nonotes ///
nodepvars noomitted interaction(" * ") ///
mgroups("CPS College Premium" "BG College Premium", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
keep(msa_anysocial) ///
scalar("controls Controls" ///
"lm MSA fixed effects") ///
title("MSA-level Effects of Prosocial Postings on College Pay Premium"\label{tab:msa}) ///
addnote("`noteshort'" ///
"* p $<$ .05; ** p $<$ .01; *** p $<$ .001 (two-tailed tests)")


corr msa_coll_gap_bg msa_anysocial if msa_keep==1
local rho3: di %6.2f r(rho)

if $presentation {
binscatter msa_coll_gap_bg msa_anysocial if msa_keep==1, ///
mcolor(blue) msymbol(circle_hollow) lcolor(black) ///
ylabel(, nogrid) graphregion(style(none) color(gs16)) ///
xtitle("MSA-level Proportion of Pro-Social Jobs") ///
ytitle("MSA-level College Wage Premium") ///
text(.41 .08 "{&rho} =`rho3'") ///
note("Note: Data from Burning Glass Technologies.")
graph save results/bin_msa_pres.gph, replace
graph export results/bin_msa_pres.pdf, replace
}

if $paper {
binscatter msa_coll_gap_bg msa_anysocial if msa_keep==1, ///
mcolor(black) msymbol(circle_hollow) lcolor(gs10) ///
ylabel(, nogrid) graphregion(style(none) color(gs16)) ///
xtitle("MSA-level Proportion of Pro-Social Jobs") ///
ytitle("MSA-level College Wage Premium (BG)") ///
text(.45 .08 "{&rho} =`rho3'")
graph save results/bin_msa.gph, replace
graph export results/bin_msa.pdf, replace

corr msa_coll_gap msa_anysocial if msa_keep==1
local rho_cps: di %6.2f r(rho)

binscatter msa_coll_gap msa_anysocial if msa_keep==1, ///
mcolor(black) msymbol(circle_hollow) lcolor(gs10) ///
ylabel(, nogrid) graphregion(style(none) color(gs16)) ///
xtitle("MSA-level Proportion of Pro-Social Jobs") ///
ytitle("MSA-level College Wage Premium (CPS)") ///
text(.522 .08 "{&rho} =`rho_cps'")
graph save results/bin_msa_cps.gph, replace
graph export results/bin_msa_cps.pdf, replace
}

}
