/*******************************************************************************
	
		build_bg.do
		5.21.2020
		Main build file for:
		"Values and Inequality"
		Nathan Wilmers and Letian Zhang
		
 	IN:
		/data/
			BG_Wage_0719.dta 
				Built by: 
				BGT_US.do (LT's build file)
				and prosocial_word_search.py (for social_meaning_count)
			oes.dta
				Built by:
				build_other.do			
			fips_service.dta
				Built by:
				build_other.do			
			msa_cps.dta
				Built by:
				build_other.do			
			oes.dta
				Built by:
				build_other.do			
			msa_volunteer.dta
				Built by:
				build_other.do
			skillcombo.dta
				Built by:
				build_skillcombo.do

	OUT:
		/data/ 
			bg_using.dta			
*******************************************************************************/
global sec1 1  // 	SECTION 1. Open BG and drop missing
global sec2 1  // 	SECTION 2. Make variables
global sec3 1  // 	SECTION 3. Merge in other data
global sec4 1  // 	SECTION 4. Diagnose sample size
global sec5 1  // 	SECTION 5. Save using dataset
*-------------------------------------------------------------------------------
* PRELIMINARIES
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
* SECTION 1. Open BG and drop missing
*-------------------------------------------------------------------------------
use data/BG_Wage_0719.dta, clear

if $sec1 {	

// Drop missing values
drop if minsalary==. | maxsalary==0
drop if edu==0
drop if naics3==-999
drop if text_length==.
drop if soc2==.
drop if msa==. | msa==-999

}
*-------------------------------------------------------------------------------
* SECTION 2. Make variables
*-------------------------------------------------------------------------------
if $sec2 {	

// State from county fips
gen state=floor(fips/1000)

drop exp2 // Funky binary variable
replace exp=0 if exp==-999 // If experience is not mentioned, assume non required

foreach var in canontitle cleantitle employers_canontitle employers_fips_canontitle soc socname onet onetname sector sectorname payfrequency salarytype jobhours taxterm college {
rename `var'2 `var'
}
rename soc2_short soc_short
decode sector, gen(sectors)
drop sector
gen sector= regexs(1) if regexm(sectors, "^([0-9][0-9])")

gen bonus=salarytype==2 | salarytype==3 // Lump comission with bonus

gen parttime=jobhours==3 // marking missing as fulltime

// Binary social meaning
gen anysocial=social_meaning_count>0

// Wage
egen salary=rowmean(minsalary maxsalary)
gen lnsalary=ln(salary)
drop if lnsalary==.

// Text length
gen lntext=ln(text_length)

// Skill count
gen lnskill_count=ln(skill_count)

// Occupation labels
label define soc 11 "Management" 13 "Business and Finance" 15 "Computer and Math" 17 "Architecture and Engineering" 19 "Science" 21 "Community and Social Services" 23 "Legal" 25 "Education" 27 "Arts and Media" 29 "Healthcare Practitioners" 31 "Healthcare Support" 33 "Protective" 35 "Food Preparation" 37 "Building and Maintenance" 39 "Personal Care" 41 "Sales" 43 "Administrative Support" 45 "Farming and Fishing" 47 "Construction and Mining" 49 "Installation and Repair" 51 "Production" 53 "Transportation" 55 "Military", replace
label values soc_short soc

label define edlabel 12 "High School" 14 "Associates" 16 "BA" 18 "Masters/Professional" 21 "Doctorate", replace
label values edu edlabel

// Sector
destring sector, replace

}
*-------------------------------------------------------------------------------
* SECTION 3. Merge in other data
*-------------------------------------------------------------------------------
if $sec3 {	
	
// Merge in skill combo
merge 1:1 bgtjobid using data/skillcombo.dta, nogen keep(3)

// Merge with OES
merge m:1 soc_short sector using data/oes_weight_soc.dta, keep(1 3)
drop if _merge==1

gen bg_tot=_N
bys soc_short sector: gen bg_cell=_N 
gen bg_share=bg_cell/bg_tot
gen weight = oes_emp_share / bg_share
sum weight, detail
replace weight=r(p99) if weight>r(p99) & weight!=.
replace weight=r(p1) if weight<r(p1)

// Share in msa-year (using weights)
bys msa year: egen msa_anysocial=wtmean(anysocial), weight(weight)

// Merge in volunteer data
merge m:1 msa using data/msa_volunteer.dta, nogen keep(1 3)

// Merge in CPS-ORG data
merge m:1 msa year using data/msa_cps.dta, nogen keep(1 3)

}

*-------------------------------------------------------------------------------
* SECTION 4. Diagnose sample size
*-------------------------------------------------------------------------------
if $sec4 {	
	
// Diagnose sample size for skillcombo
gen unit=1

forval c=0/1 {
preserve 
keep if college==`c'

local group0 unit
local group1 skillcombo
local group2 skillcombo year 
local group3 skillcombo year soc
local group3 skillcombo soc
local group4 skillcombo year onet 
local group5 skillcombo year soc msa naics3 
local group6 skillcombo year onet msa naics3 
local group7 skillcombo year onet msa naics3 employers

forval x=0/7 {
bys `group`x'': egen anysocialm=mean(anysocial)
di "`group`x''; College==`c'"
count if anysocialm!=1 & anysocialm!=0
drop anysocialm
}
restore
}
}
*-------------------------------------------------------------------------------
* SECTION 5. Save using dataset
*-------------------------------------------------------------------------------
if $sec5 {	
	
// Keep only key variables
keep bgtjobid year lnsalary edu anysocial lntext text soc socname onet sector sectorname college skillcombo msa naics3 employers weight soc_short msa_anysocial skill_count cleantitle canontitle text lnskill_count exp bonus parttime  anysocial msa_female msa_pubsect msa_union msa_volunteer msa_coll_gap fips msa_*

label var year "Year"
label var lnsalary "log(Annual Earnings)"
label var edu "Education"
label var anysocial "Pro-social"
label var msa_anysocial "Pro-social MSA share"
label var lntext "log(Text Length)"
label var soc "Occupation"
label var sector "Sector"
label var college "College"
label var skill_count "Number of Skills Listed"
label var lnskill_count "log(Number of Skills Listed)"
label var exp "Experience Required"
label var bonus "Bonus or commission"
label var parttime "Part-time"

label define anysocial 1 "Pro-social"
label values anysocial anysocial

label define college 1 "College"
label values college college

compress
save data/bg_using.dta, replace

}
