/*******************************************************************************
	
		build_other.do
		5.21.2020
		Auxilliary data build file for:
		"Values and Inequality"
		Nathan Wilmers and Letian Zhang
		
 	IN:
		/data/
			national_M2019_dl.xlsx
			oes_research_2019_allsectors.xlsx
				From:
				https://www.bls.gov/oes/tables.htm
			skillcombo.dta
				Built by:
				build_skillcombo.do
			Colleges_and_Universities_Campuses.csv
				From: 
				https://hifld-geoplatform.opendata.arcgis.com/datasets/colleges-and-universities-campuses/data
			WM-2019-`kind'-Ranking.xlsx
				From: 
				https://washingtonmonthly.com/2019college-guide
			cps_00050.dat
				From:
				IPUMS-CPS (wilmers@mit.edu account 00050, volunteer supplement only)
			cepr_org_`year'.zip
				From: CEPR download in data
			
	OUT:
		/data/ 
			oes.dta
			fips_service.dta
			msa_cps.dta
			oes.dta
			msa_volunteer.dta
		
*******************************************************************************/
global sec1 1  // 	SECTION 1. OES make weights
global sec2 1  // 	SECTION 2. Assemble universities data
global sec3 1  // 	SECTION 3. Build CPS-ORG data
global sec4 1  // 	SECTION 4. Build CPS volunteer data
*-------------------------------------------------------------------------------
* PRELIMINARIES
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
* SECTION 1. OES make weights
*-------------------------------------------------------------------------------
if $sec1 {	
	
import excel using "data/natsector_M2019_dl.xlsx", firstrow clear

gen naics2=regexs(0) if regexm(naics, "^[0-9][0-9]")
replace naics2="92" if naics2=="99"
gen soc5=regexs(0) if regexm(occ_code, "^[0-9][0-9][-][0-9][0-9][0-9]")
gen soc4=regexs(0) if regexm(occ_code, "^[0-9][0-9][-][0-9][0-9]")
gen soc3=regexs(0) if regexm(occ_code, "^[0-9][0-9][-][0-9]")
gen soc2=regexs(0) if regexm(occ_code, "^[0-9][0-9]")

keep soc2 naics2 tot_emp h_mean h_median
drop if soc2=="00"

foreach num in tot_emp h_mean h_median {
	destring `num', replace force
}

bys naics2 soc: egen oes_emp=total(tot_emp)
bys naics2 soc: egen oes_wage_mean=wtmean(h_mean), weight(tot_emp)
bys naics2 soc: egen oes_wage_median=wtmean(h_median), weight(tot_emp)
drop tot_emp h_mean h_median

duplicates drop naics2 soc2, force

egen total=total(oes_emp)
gen oes_emp_share=oes_emp/total
drop oes_emp total

destring naics2, gen(sector)
drop naics2
destring soc2, gen(soc_short)
drop soc2

compress
save data/oes_weight_soc.dta, replace

}

*-------------------------------------------------------------------------------
* SECTION 2. Assemble universities data
*-------------------------------------------------------------------------------

if $sec2 {	

// Source for geographical data:
*https://hifld-geoplatform.opendata.arcgis.com/datasets/colleges-and-universities-campuses/data
clear
import delimited using data/Colleges_and_Universities_Campuses.csv, varnames(1)

keep name countyfips
destring countyfips, gen(fips) force
drop countyfips

gen namecl= regexs(1) if regexm(name, "(.*)[-](.*)$")
replace namecl=name if namecl==""
egen namecl2=sieve(namecl), keep(a space)
drop namecl
rename namecl2 namecl
replace namecl=upper(namecl)
replace namecl=trim(namecl)

gen idusing=_n

save data/college_fips.dta, replace

// Source for service-orientation
*https://washingtonmonthly.com/2019college-guide
foreach kind in Bachelors Masters-Universities National-Universities Liberal-Arts {
clear
import excel using data/WM-2019-`kind'-Ranking.xlsx, firstrow case(lower)

egen servicerankm=max(servicerank)
gen servicepct=servicerank/servicerankm
rename numberofpellgraduates pell

keep name servicepct pell offederalworkstudyfundssp peacecorpsrank

save data/`kind'rank.dta, replace
}

clear
foreach kind in Bachelors Masters-Universities National-Universities Liberal-Arts {
append using data/`kind'rank.dta
}

// Merge together
egen namecl=sieve(name), keep(a space)
replace namecl=upper(namecl)
replace namecl=trim(namecl)
gen namecl2= regexs(1) if regexm(namecl, "(.*)([A-Z][A-Z])$")
drop namecl
rename namecl2 namecl

gen idmaster=_n

reclink namecl using data/college_fips.dta, idmaster(idmaster) idusing(idusing) gen(score)

sort idmaster score
by idmaster: gen rank=_n

keep fips servicepct pell offederalworkstudyfundssp peacecorpsrank

foreach var in servicepct offederalworkstudyfundssp peacecorpsrank {
bys fips: egen fips_`var'uw=mean(`var')
bys fips: egen fips_`var'w=wtmean(`var'), weight(pell)
}

collapse (mean) fips_servicepctw fips_servicepctuw fips_offederalworkstudyfundsspw fips_offederalworkstudyfundsspuw fips_peacecorpsrankw fips_peacecorpsrankuw, by(fips)

save data/fips_service.dta, replace

}

*-------------------------------------------------------------------------------
* SECTION 3. Build CPS-ORG data
*-------------------------------------------------------------------------------

if $sec3 {	

clear
forval year=2007/2019 {
if inlist(`year',2008,2009) continue
copy http://ceprdata.org/wp-content/cps/data/cepr_org_`year'.zip "cepr_org_`year'.zip", replace
unzipfile "cepr_org_`year'.zip"
append using "cepr_org_`year'.dta", force
keep year age educ female wbho empl pubsect union state ind_nber ind_2d ind03 ind09 ind12 ind14 ind_m03 docc03 occ70 occ80 occ03 occ11 occ12 rw* wage* orgwgt metro cow1 smsastat05 smsastat14 nilf unem
rm "cepr_org_`year'.zip"
rm "cepr_org_`year'.dta"
}

// Basic cleaning
gen msa=smsastat14
replace msa=smsastat05 if msa==.

foreach var in rw wage3 wage4 {
gen ln`var'=ln(`var')
}
rename lnrw lnsalary
rename orgwgt weight

gen college=educ>3

// Unemployed by educ
keep if unem | empl
bys year msa: egen msa_unemp=wtmean(unem), weight(weight)
bys year msa: egen collunemt=wtmean(unem) if college==1, weight(weight)
bys year msa: egen nocollnunemt=wtmean(unem) if college==0, weight(weight)
bys year msa: egen msa_collunem=max(collunemt)
bys year msa: egen msa_nocollnunem=max(nocollnunemt)

// College share
bys msa year: egen msa_coll_cps=wtmean(college), weight(weight)

// Among unemployed
keep if empl==1

// Average age of employed workers
bys msa year: egen msa_age=wtmean(age), weight(weight)

// College wage premium
bys year msa: egen collnsalaryt=wtmean(lnsalary) if college==1, weight(weight)
bys year msa: egen nocollnsalaryt=wtmean(lnsalary) if college==0, weight(weight)
bys year msa: egen collnsalary=max(collnsalaryt)
bys year msa: egen nocollnsalary=max(nocollnsalaryt)
gen msa_coll_gap=collnsalary-nocollnsalary

// Union density
bys msa year: egen msa_union=wtmean(union), weight(weight)

// Public sector
bys msa year: egen msa_pubsect=wtmean(pubsect), weight(weight)

// Female
bys msa year: egen msa_female=wtmean(female), weight(weight)

// Final
bys msa year: gen count=_n
drop if count>1

keep year msa*

save data/msa_cps.dta, replace

}

*-------------------------------------------------------------------------------
* SECTION 4. Build CPS volunteer data
*-------------------------------------------------------------------------------

if $sec4 {	

clear
quietly infix               ///
  int     year       1-4    ///
  byte    statefip   5-6    ///
  byte    cbsasz     7-8    ///
  long    metfips    9-13   ///
  byte    individcc  14-14  ///
  int     faminc     15-17  ///
  byte    pernum     18-19  ///
  double  wtfinl     20-33  ///
  double  cpsidp     34-47  ///
  byte    empstat    48-49  ///
  byte    labforce   50-50  ///
  int     occ2010    51-54  ///
  int     ind1990    55-57  ///
  int     educ       58-60  ///
  byte    vlstatus   61-62  ///
  byte    vltorg1    63-64  ///
  byte    vltorg2    65-66  ///
  byte    vltorg3    67-68  ///
  byte    vltorg4    69-70  ///
  byte    vltorg5    71-72  ///
  byte    vltorg6    73-74  ///
  byte    vltorg7    75-76  ///
  long    vlhallorg  77-81  ///
  using `"data/cps_00050.dat"'

replace wtfinl    = wtfinl    / 10000

format wtfinl    %14.4f
format cpsidp    %14.0f

drop if vlstatus>2
bys metfips: egen msa_volunteer=wtmean(vlstatus==1), weight(wtfinl)

keep metfips msa_volunteer
duplicates drop
rename metfips msa

save data/msa_volunteer.dta, replace

}

